@@ -514,7 +514,7 @@ class SFINCS:
         if self.input.outputformat[0:3] == "net":
             ddd=xr.open_dataset(zsmax_file)
 #            zsmx=ddd.zsmax.values
-            zsmax=ddd.zsmax.values.max(axis=0)
+            zsmax=np.transpose(np.nanmax(ddd.zsmax.values, axis=0))
             return zsmax
 
         else:
